# HKBOT Automation

a program created to help complete tasks from hkbot telegram

## List of Hkbot Telegram

| no  | name                           | currency | link                                                                         |
| --- | ------------------------------ | -------- | ---------------------------------------------------------------------------- |
| 1   | Earn TRX or Advertise - HKBot  | TRX      | [https://t.me/hkearn_trx_bot](https://t.me/hkearn_trx_bot?start=629438076)   |
| 2   | Earn BCH or Advertise - HKBot  | BCH      | [https://t.me/hkearn_bch_bot](https://t.me/hkearn_bch_bot?start=629438076)   |
| 3   | Earn BNB or Advertise - HKBot  | BNB      | [https://t.me/hkearn_bnb_bot](https://t.me/hkearn_bnb_bot?start=629438076)   |
| 4   | Earn LTC or Advertise - HKBot  | LTC      | [https://t.me/hkearn_ltc_bot](https://t.me/hkearn_ltc_bot?start=629438076)   |
| 5   | Earn USDT or Advertise - HKBot | USDT     | [https://t.me/hkearn_usdt_bot](https://t.me/hkearn_usdt_bot?start=629438076) |
| 6   | Earn DOGE or Advertise - HKBot | DOGE     | [https://t.me/hkearn_doge_bot](https://t.me/hkearn_doge_bot?start=629438076) |
| 7   | Earn ETH or Advertise - HKBot  | ETH      | [https://t.me/HKEarnETHBot](https://t.me/HKEarnETHBot?start=629438076)       |
| 8   | Earn BTC or Advertise - HKBot  | BTC      | [https://t.me/HKEarnBTCBot](https://t.me/HKEarnBTCBot?start=629438076)       |
---


## Install Requirements
1. install python language
2. install python library manager (pip)

#### Windows
download python from http://python.org (already including python library manager)

#### Linux
```
sudo apt update
sudo apt upgrade
sudo apt install python3 python3-pip
```

## Install / Build Program

just type this command below in command line (terminal / cmd)

#### Windows
```
python -m pip install hkbot
```
#### Linux
```
python3 -m pip install hkbot
```

## Run Program

first create the config with command below
```
hkbot-create-config
```
second, run the main command 
```
hkbot
```